@@ -112,6 +112,7 @@ struct apk_name {
 	unsigned int foreach_genid;
 	union {
 		struct apk_solver_name_state ss;
+		unsigned char state_buf[sizeof(struct apk_solver_name_state)];
 		void *state_ptr;
 		int state_int;
 	};
@@ -179,6 +180,7 @@ struct apk_database {
 	struct apk_repository_tag repo_tags[APK_MAX_TAGS];
 	struct apk_id_cache id_cache;
 	struct apk_atom_pool atoms;
+	struct apk_string_array *filename_array;
 
 	struct {
 		unsigned stale, updated, unavailable;
@@ -236,7 +238,8 @@ struct apk_db_file *apk_db_file_query(struct apk_database *db,
 #define APK_OPENF_NO_INSTALLED_REPO	0x0200
 #define APK_OPENF_CACHE_WRITE		0x0400
 #define APK_OPENF_NO_AUTOUPDATE		0x0800
-#define APK_OPENF_NO_CMDLINE_REPOS     0x1000
+#define APK_OPENF_NO_CMDLINE_REPOS	0x1000
+#define APK_OPENF_ALLOW_ARCH		0x4000
 
 #define APK_OPENF_NO_REPOS	(APK_OPENF_NO_SYS_REPOS |	\
 				 APK_OPENF_NO_INSTALLED_REPO)
